Crate oicana

Crate oicana 

Oicana

Dynamic PDF Generation based on Typst

With this library, you can compile Oicana templates from Rust code.

Structs

Template
A prepared Oicana Template

Enums

TemplateInitializationError
An error occurred while initiating the template

Functions

configure_automatic_cache_eviction
Configure automatic cache eviction after each compilation.
evict_cache
Evict cached compilation artifacts from the global comemo cache.