Oicana
Dynamic PDF Generation based on Typst
With this library, you can compile Oicana templates from Rust code.
Structs
- Template
- A prepared Oicana Template
Enums
- Template
Initialization Error - An error occurred while initiating the template
Functions
- configure_
automatic_ cache_ eviction - Configure automatic cache eviction after each compilation.
- evict_
cache - Evict cached compilation artifacts from the global comemo cache.